rconst: Generate Constant Variable

View source: R/rconst.R

rconstR Documentation

Generate Constant Variable

Description

A random number generator returning only a constant. This can be used to set dropout time. Currently it is the default value of dropout time, with value = Inf.

This function can also be used as a generator of endpoint() if a constant endpoint is needed.

Usage

rconst(n, value)

Arguments

n

integer. Number of observations.

value

scalar. Value of constant observations.

Value

a numeric vector of length n with all entries equal to value.


TrialSimulator documentation built on Sept. 4, 2026, 5:08 p.m.