| regimen | R Documentation |
Define a regimen of a trial. This is a user-friendly wrapper for
the class constructor Regimens$new(). Users who are not familiar with
the concept of classes may consider using this wrapper directly.
A regimen defines the rules to select patients who switch treatments, to determine the time of switching, and to update patients' endpoint data.
regimen(what, when, how, ...)
what |
a function determining whether patients' data would be
updated due to switching treatment. It takes |
when |
a function determining the time at which a patient switches
to another treatment regimen, measured from the time of enrollment.
It takes |
how |
a function updating patients' data after treatment switching.
Only modified columns and |
... |
(optional) named arguments to be passed to one or more of
|
an object of R6 class Regimens, representing a treatment regimen.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.