update_sample_ratio: Updating Sampling Ratios of Existing Arms in a Trial

View source: R/update_sample_ratio.R

update_sample_ratioR Documentation

Updating Sampling Ratios of Existing Arms in a Trial

Description

update sample ratios of arms. This could be called after an arm is added or removed. Sample ratios can be updated for any existing arms.

This is a user-friendly wrapper of the member function of trial, i.e., Trials$update_sample_ratio(), which is used in vignettes. Users who are not familiar with the concept of classes may consider using this wrapper directly.

Usage

update_sample_ratio(trial, arm_names, sample_ratios)

Arguments

trial

a trial object returned by trial().

arm_names

character vector. Name of arms.

sample_ratios

numeric vector. New sample ratios of arms. If sample ratio is a whole number, the permuted block randomization is adopted; otherwise, sample() will be used instead, which can cause imbalance between arms by chance. However, this is usually fine for simulation.

Value

no return value, called for its side effect of updating trial.


TrialSimulator documentation built on Sept. 4, 2026, 5:08 p.m.