Compute Constant Rates of Piecewise Exponential Distribution
Source:R/solvePiecewiseConstantExponentialDistribution.R
solvePiecewiseConstantExponentialDistribution.RdThis function computes the rate parameters lambda in each of the time
windows. lambda are natural parameters of piecewise exponential
distribution, but in practice, users may define the distribution by
specifying the survival probabilities at time points where event rates
change.
This function returns a data frame, which can be used as input of the
argument risk of the data generator PiecewiseConstantExponentialRNG.