View source: R/update_sample_ratio.R
| update_sample_ratio | R Documentation |
update sample ratios of arms. This could be called after an arm is added or removed. Sample ratios can be updated for any existing arms.
This is a user-friendly wrapper of the member function of trial, i.e.,
Trials$update_sample_ratio(), which is used in vignettes.
Users who are not familiar with the concept of classes may consider using
this wrapper directly.
update_sample_ratio(trial, arm_names, sample_ratios)
trial |
a trial object returned by |
arm_names |
character vector. Name of arms. |
sample_ratios |
numeric vector. New sample ratios of arms. If sample
ratio is a whole number, the permuted block randomization is adopted;
otherwise, |
no return value, called for its side effect of updating trial.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.